@@ -5,6 +5,8 @@
 #	Copyright (C) 1999, 2000, Andrew Arensburger.
 #	You may distribute this file under the terms of the Artistic
 #	License, as specified in the README file.
+#
+# $Id: Memo.pm,v 1.13 2002/11/07 14:12:05 arensb Exp $
 
 use strict;
 package Palm::Memo;
@@ -13,7 +15,7 @@ use Palm::StdAppInfo();
 use vars qw( $VERSION @ISA );
 
 # One liner, to allow MakeMaker to work.
-$VERSION = '1.011_01';
+$VERSION = do { my @r = (q$Revision: 1.13 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @ISA = qw( Palm::StdAppInfo Palm::Raw );
 
@@ -201,17 +203,9 @@ sub PackRecord
 1;
 __END__
 
-=head1 SOURCE CONTROL
-
-The source is in Github:
-
-	http://github.com/briandfoy/p5-Palm/tree/master
-	
 =head1 AUTHOR
 
-Alessandro Zummo, C<< <a.zummo@towertech.it> >>
-
-Currently maintained by brian d foy, C<< <bdfoy@cpan.org> >>
+Andrew Arensburger E<lt>arensb@ooblick.comE<gt>
 
 =head1 SEE ALSO
 
