@@ -5,6 +5,8 @@
 #	Copyright (C) 1999, 2000, Andrew Arensburger.
 #	You may distribute this file under the terms of the Artistic
 #	License, as specified in the README file.
+#
+# $Id: StdAppInfo.pm,v 1.19 2002/11/07 14:27:28 arensb Exp $
 
 use strict;
 package Palm::StdAppInfo;
@@ -15,7 +17,7 @@ use vars qw( $VERSION @ISA $error );
 	# $error acts like $! in that it reports the error that occurred
 
 # One liner, to allow MakeMaker to work.
-$VERSION = '1.011_01';
+$VERSION = do { my @r = (q$Revision: 1.19 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @ISA = qw( Palm::Raw );
 
@@ -285,9 +287,6 @@ sub parse_StdAppInfo
 	my @uniqueIDs;		# Array of category IDs
 	my $lastUniqueID;	# Not sure what this is
 
-	return undef
-		if length $data < 4+(categoryLength*numCategories)+numCategories;
-
 	if (!defined($nopadding))
 	{
 		$nopadding = 0;
@@ -617,17 +616,9 @@ sub renameCategory
 1;
 __END__
 
-=head1 SOURCE CONTROL
-
-The source is in Github:
-
-	http://github.com/briandfoy/p5-Palm/tree/master
-	
 =head1 AUTHOR
 
-Alessandro Zummo, C<< <a.zummo@towertech.it> >>
-
-Currently maintained by brian d foy, C<< <bdfoy@cpan.org> >>
+Andrew Arensburger E<lt>arensb@ooblick.comE<gt>
 
 =head1 SEE ALSO
 
